@@ -23,11 +23,10 @@
 
 #include "plugin.h"
 #include "cfg.h"
+#include "template/function.h"
 #include "plugin-types.h"
 
 #include "number-funcs.c"
-#include "cond-funcs.c"
-#include "string-funcs.c"
 
 #if GLIB_CHECK_VERSION(2,32,0)
 #include "state-funcs.c"
@@ -40,17 +39,15 @@
 static Plugin basicfuncs_plus_plugins[] =
 {
   TEMPLATE_FUNCTION_PLUGIN(tf_num_divx, "//"),
-  TEMPLATE_FUNCTION_PLUGIN(tf_or, "or"),
-  TEMPLATE_FUNCTION_PLUGIN(tf_string_padding, "padding"),
 #if GLIB_CHECK_VERSION(2,32,0)
   TEMPLATE_FUNCTION_PLUGIN(tf_state, "state"),
 #endif
 };
 
 gboolean
-basicfuncs_plus_module_init(GlobalConfig *cfg, CfgArgs *args)
+basicfuncs_plus_module_init(PluginContext *context, CfgArgs *args)
 {
-  plugin_register(cfg, basicfuncs_plus_plugins,
+  plugin_register(context, basicfuncs_plus_plugins,
                   G_N_ELEMENTS(basicfuncs_plus_plugins));
   return TRUE;
 }
@@ -58,7 +55,7 @@ basicfuncs_plus_module_init(GlobalConfig *cfg, CfgArgs *args)
 const ModuleInfo module_info =
 {
   .canonical_name = "basicfuncs-plus",
-  .version = VERSION,
+  .version = SYSLOG_NG_VERSION,
   .description = "The basicfuncs-plus module provides some additional template functions for syslog-ng.",
   .core_revision = VERSION_CURRENT_VER_ONLY,
   .plugins = basicfuncs_plus_plugins,
