@@ -311,11 +311,11 @@ rss_dd_free (LogPipe *s)
 }
 
 LogDriver *
-rss_dd_new (void)
+rss_dd_new (GlobalConfig *cfg)
 {
   RssDestDriver *self = g_new0 (RssDestDriver, 1);
 
-  log_dest_driver_init_instance (&self->super);
+  log_dest_driver_init_instance (&self->super, cfg);
   self->super.super.super.queue = rss_dd_queue;
   self->super.super.super.init = rss_dd_init;
   self->super.super.super.deinit = rss_dd_deinit;
@@ -334,15 +334,15 @@ static Plugin rss_plugin = {
 };
 
 gboolean
-rss_module_init (GlobalConfig * cfg, CfgArgs * args)
+rss_module_init (PluginContext *context, CfgArgs * args)
 {
-  plugin_register (cfg, &rss_plugin, 1);
+  plugin_register (context, &rss_plugin, 1);
   return TRUE;
 }
 
 const ModuleInfo module_info = {
   .canonical_name = "rss",
-  .version = VERSION,
+  .version = SYSLOG_NG_VERSION,
   .description = "The rss module is a destination driver to offer logs in RSS feed.",
   .core_revision = VERSION_CURRENT_VER_ONLY,
   .plugins = &rss_plugin,
